# PayNexus

## プログラム言語

<!-- シールド一覧 -->
<!-- 該当するプロジェクトの中から任意のものを選ぶ-->
<p style="display: inline">
  <img src="https://img.shields.io/badge/-Python-F2C63C.svg?logo=python&style=for-the-badge">
</p>

## 目次

1. [プロジェクトについて](#プロジェクトについて)
2. [環境](#環境)
3. [モジュールについて](#モジュールについて)

## プロジェクトについて

PythonからPaypayを操作できる非公式モジュールです。


## 環境

<!-- 言語、フレームワーク、ミドルウェア、インフラの一覧とバージョンを記載 -->

| 言語・フレームワーク  | バージョン |
| --------------------- | ---------- |
| Python                | 3.9.19     |

パッケージのバージョンは requirements.txt を参照してください

# モジュールについて
## タスク
- [x] ログイン機能

## ドキュメント
| 関数  | 説明 |
| --------------------- | ---------- |
|login|Paypayアカウントにログイン|
|resend_otp|認証コードを再送信|

## 使用例
```python
print("Coming Soon...")
```

※機能説明はリリースまでには完成させます（一部機能しか書いてません）